Documentation
¶
Overview ¶
Package putlib implements common plumbing for copying file trees from a local filesystem into FFS representation.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var Default = Config{FilterName: ".ffsignore"}
Functions ¶
Types ¶
type Config ¶
type Config struct {
Verbose bool // emit diagnostic output
XAttr bool // capture extended attributes
NoStat bool // do not capture stat metadata
FilterName string // name of filter file to read
}
Config carries settings for storing files into an FFS store.
Click to show internal directories.
Click to hide internal directories.