Documentation
¶
Overview ¶
Package exportlib defines common plumbing for exporting file trees into archives and other filesystems.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
Root string // prefix output paths with this directory
IncludeXAttr bool // include extended attributes, if possible
OmitStat bool // omit permissions and modification times
Update bool // update or replace existing targets
DebugOutput io.Writer // write detailed debug output here
}
Config carries shared settings for exporting file trees from a store. A zero value is ready for use.
func (Config) ExportToOS ¶
ExportToOS recursively exports the contents of tree into the specified root in the native filesystem. It will report an error if c.Root == "".
func (Config) ExportToTar ¶
ExportToTar recursively exports the contents of tree to tw.
Click to show internal directories.
Click to hide internal directories.